bookTitle

# XMLRésuméLibrary: User Guide

birth | Element Reference | break

## Name

bookTitle — A title of a book or similar work

## Synopsis

### Content Model

    (#PCDATA|link)*

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `bookTitle` element marks the title of a book, magazine, journal, anthology, or other similar work. To denote the title of a sub-work (like an article), see `artTitle`.

### Parents

`bookTitle` may be contained in these elements: `pub`

## See Also

`artTitle`.

## Examples

    <pub>
      <bookTitle>Tropical Siberian Vacations</bookTitle>
      <author>Boris Tzchleikovsy</author>
    </pub>

    <pub>
      <bookTitle>Children's Bedtime Stories</bookTitle>
      <artTitle>Jack the Axe Murderer</artTitle>
      <author>Caroline Black</author>
    </pub>

    <pub>
      <artTitle>Global Commodities Market Downturn</artTitle>
      <bookTitle>The Economist</bookTitle>
      <pubDate>
        <month>June</month>
        <year>1992</year>
      </pubdate>
    </pub>

birth | Element Reference | break